@@ -874,12 +874,17 @@ void __connman_service_auto_connect(void)
 	}
 }
 
-static void reply_pending(struct connman_service *service, int error)
+static void remove_timeout(struct connman_service *service)
 {
 	if (service->timeout > 0) {
 		g_source_remove(service->timeout);
 		service->timeout = 0;
 	}
+}
+
+static void reply_pending(struct connman_service *service, int error)
+{
+	remove_timeout(service);
 
 	if (service->pending != NULL) {
 		if (error > 0) {
@@ -935,6 +940,40 @@ static gboolean connect_timeout(gpointer user_data)
 	return FALSE;
 }
 
+static void set_reconnect_state(struct connman_service *service,
+						connman_bool_t reconnect)
+{
+	if (service->network != NULL) {
+		struct connman_device *device;
+
+		device = connman_network_get_device(service->network);
+
+		__connman_device_set_reconnect(device, reconnect);
+
+		return;
+	}
+
+	if (service->device != NULL)
+		__connman_device_set_reconnect(service->device,
+							reconnect);
+}
+
+static connman_bool_t get_reconnect_state(struct connman_service *service)
+{
+	if (service->network != NULL) {
+		struct connman_device *device;
+
+		device = connman_network_get_device(service->network);
+
+		return __connman_device_get_reconnect(device);
+	}
+
+	if (service->device != NULL)
+		return __connman_device_get_reconnect(service->device);
+
+	return FALSE;
+}
+
 static DBusMessage *connect_service(DBusConnection *conn,
 					DBusMessage *msg, void *user_data)
 {
@@ -966,6 +1005,8 @@ static DBusMessage *connect_service(DBusConnection *conn,
 
 	service->pending = dbus_message_ref(msg);
 
+	set_reconnect_state(service, FALSE);
+
 	err = __connman_service_connect(service);
 	if (err < 0) {
 		if (err == -ENOKEY) {
@@ -1002,6 +1043,8 @@ static DBusMessage *disconnect_service(DBusConnection *conn,
 
 	service->ignore = TRUE;
 
+	set_reconnect_state(service, FALSE);
+
 	err = __connman_service_disconnect(service);
 	if (err < 0) {
 		if (err != -EINPROGRESS)
@@ -1398,7 +1441,17 @@ int __connman_service_indicate_state(struct connman_service *service,
 	service->state = state;
 	state_changed(service);
 
+	if (state == CONNMAN_SERVICE_STATE_IDLE) {
+		connman_bool_t reconnect;
+
+		reconnect = get_reconnect_state(service);
+		if (reconnect == TRUE)
+			__connman_service_auto_connect();
+	}
+
 	if (state == CONNMAN_SERVICE_STATE_READY) {
+		set_reconnect_state(service, TRUE);
+
 		connman_service_set_favorite(service, TRUE);
 
 		reply_pending(service, 0);
@@ -1422,6 +1475,7 @@ int __connman_service_indicate_state(struct connman_service *service,
 		if (service->failcounter++ < MAX_CONNECT_RETRIES) {
 			connman_warn("Connecting again (try %d)",
 						service->failcounter);
+			remove_timeout(service);
 			__connman_service_disconnect(service);
 			__connman_service_connect(service);
 			return 0;
@@ -1783,6 +1837,8 @@ done:
 		goto failed;
 	}
 
+	set_reconnect_state(service, FALSE);
+
 	__connman_device_disconnect(device);
 
 	if (passphrase != NULL) {
